{% load i18n %}
{% if user.is_superuser %}
	<div>
		<a id="instant_open" v-on:click="toggleInstantForm()" href="" style="display:none">
			<i class="fa fa-close"></i>&nbsp;{% trans "Close" %}
		</a>
		<a id="instant_close" v-on:click="toggleInstantForm()" href="">
			<i class="fa fa-flash"></i>&nbsp;{% trans "Publish" %}
		</a>
		
	</div>
{% endif %}