{% load staticfiles vv_tags %}

<div id="topbar">
	<div id="instant_msgs" style="display:none;font-size:160%">{% include "instant/widgets/counter.html" %}</div>
</div>
<div class="gds-s" style="display:inline-block;position:relative;top:11px;left:2em;font-size:220%;color:white">
	<span class="hidden-xxs">
		<a href="/">Django Instant</a>
	</span>
</div>
{% if "presence"|is_installed %}
	<div style="display:inline-block;position:relative;top:1em;left:1.2em">{% include "presence/widget.html" %}</div>
{% endif %}