<div id="warning-msg" class="primary-msg text-center" style="display:none">
	<div class="pull-right" style="margin:0.8em 1em 0 0">
		<a href="" @click="closeWarningMsg()"><i class="fa fa-close fa-2x" style="color:grey"></i></a>
	</div>
	<div class="alert alert-warning" v-html="warningMsg"></div>
</div>