<div id="info-msg" class="text-center" style="display:none">
	<div class="pull-right" style="margin:0.8em 1em 0 0">
		<a href="" @click="closeInfoMsg()"><i class="fa fa-close fa-2x" style="color:grey"></i></a>
	</div>
	<div class="well well-lg" v-html="infoMsg"></div>
</div>